searchData={"items":[{"type":"module","title":"UUIDv7","doc":"UUIDv7 for Elixir.\n\nUsed for generating version 7 UUIDs using microseconds for increased clock\nprecision.\n\nIncludes `Ecto.Type` implementations.","ref":"UUIDv7.html"},{"type":"module","title":"Examples - UUIDv7","doc":"iex> UUIDv7.generate()\n    \"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\"\n\n    iex> UUIDv7.bingenerate()\n    <<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>","ref":"UUIDv7.html#module-examples"},{"type":"function","title":"UUIDv7.bingenerate/0","doc":"Generates a version 7 UUID in the binary format.","ref":"UUIDv7.html#bingenerate/0"},{"type":"function","title":"Example - UUIDv7.bingenerate/0","doc":"iex> UUIDv7.bingenerate()\n    <<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>","ref":"UUIDv7.html#bingenerate/0-example"},{"type":"function","title":"UUIDv7.cast/1","doc":"Casts either a string in the canonical, human-readable UUID format or a\n16-byte binary to a UUID in its canonical, human-readable UUID format.\n\nIf `uuid` is neither of these, `:error` will be returned.\n\nSince both binaries and strings are represent as binaries, this means some\nstrings you may not expect are actually also valid UUIDs in their binary form\nand so will be casted into their string form.","ref":"UUIDv7.html#cast/1"},{"type":"function","title":"Examples - UUIDv7.cast/1","doc":"iex> raw = <<1, 141, 236, 237, 26, 200, 116, 82, 179, 112, 220, 56, 9, 179, 208, 93>>\n    iex> UUIDv7.cast(raw)\n    {:ok, \"018deced-1ac8-7452-b370-dc3809b3d05d\"}\n\n    iex> UUIDv7.cast(\"018deced-1ac8-7452-b370-dc3809b3d05d\")\n    {:ok, \"018deced-1ac8-7452-b370-dc3809b3d05d\"}\n\n    iex> UUIDv7.cast(\"warehouse worker\")\n    {:ok, \"77617265-686f-7573-6520-776f726b6572\"}","ref":"UUIDv7.html#cast/1-examples"},{"type":"function","title":"UUIDv7.cast!/1","doc":"Same as `cast/1` but raises `Ecto.CastError` on invalid arguments.","ref":"UUIDv7.html#cast!/1"},{"type":"function","title":"UUIDv7.decode/1","doc":"Decode a string representation of a UUID to the raw binary version.","ref":"UUIDv7.html#decode/1"},{"type":"function","title":"Example - UUIDv7.decode/1","doc":"iex> UUIDv7.decode(\"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\")\n    <<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>","ref":"UUIDv7.html#decode/1-example"},{"type":"function","title":"UUIDv7.dump/1","doc":"Converts a string representing a UUID into a raw binary.","ref":"UUIDv7.html#dump/1"},{"type":"function","title":"UUIDv7.dump!/1","doc":"Same as `dump/1` but raises `Ecto.ArgumentError` on invalid arguments.","ref":"UUIDv7.html#dump!/1"},{"type":"function","title":"UUIDv7.embed_as/1","doc":"","ref":"UUIDv7.html#embed_as/1"},{"type":"function","title":"UUIDv7.encode/1","doc":"Encode a raw UUID to the string representation.","ref":"UUIDv7.html#encode/1"},{"type":"function","title":"Example - UUIDv7.encode/1","doc":"iex> UUIDv7.encode(<<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>)\n    \"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\"","ref":"UUIDv7.html#encode/1-example"},{"type":"function","title":"UUIDv7.equal?/2","doc":"","ref":"UUIDv7.html#equal?/2"},{"type":"function","title":"UUIDv7.from_timestamp/1","doc":"Generates a version 7 UUID from an existing microsecond timestamp.","ref":"UUIDv7.html#from_timestamp/1"},{"type":"function","title":"Examples - UUIDv7.from_timestamp/1","doc":"iex> timestamp = System.system_time(:microsecond)\n    iex> UUIDv7.from_timestamp(timestamp)\n    <<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>\n\n    iex> timestamp = DateTime.utc_now()\n    iex> UUIDv7.from_timestamp(timestamp)\n    <<1, 142, 144, 216, 6, 232, 127, 159, 191, 215, 103, 48, 186, 152, 165, 27>>","ref":"UUIDv7.html#from_timestamp/1-examples"},{"type":"function","title":"UUIDv7.generate/0","doc":"Generates a version 7 UUID using microseconds for increased clock precision.","ref":"UUIDv7.html#generate/0"},{"type":"function","title":"Example - UUIDv7.generate/0","doc":"iex> UUIDv7.generate()\n    \"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\"","ref":"UUIDv7.html#generate/0-example"},{"type":"function","title":"UUIDv7.load/1","doc":"Converts a binary UUID into a string.","ref":"UUIDv7.html#load/1"},{"type":"function","title":"UUIDv7.load!/1","doc":"Same as `load/1` but raises `Ecto.ArgumentError` on invalid arguments.","ref":"UUIDv7.html#load!/1"},{"type":"type","title":"UUIDv7.raw/0","doc":"A raw binary representation of a UUID.","ref":"UUIDv7.html#t:raw/0"},{"type":"type","title":"UUIDv7.t/0","doc":"A hex-encoded UUID string.","ref":"UUIDv7.html#t:t/0"},{"type":"extras","title":"UUIDv7","doc":"# UUIDv7\n\n[![CI](https://github.com/ryanwinchester/uuidv7/actions/workflows/ci.yml/badge.svg)](https://github.com/ryanwinchester/uuidv7/actions/workflows/ci.yml)\n [![Hex.pm](https://img.shields.io/hexpm/v/uuid_v7)](https://hex.pm/packages/uuid_v7)\n [![Hex.pm](https://img.shields.io/hexpm/dt/uuid_v7)](https://hex.pm/packages/uuid_v7)\n [![Hex.pm](https://img.shields.io/hexpm/l/uuid_v7)](https://github.com/ryanwinchester/uuidv7/blob/main/LICENSE)\n\nUUIDv7 for Elixir and (optionally) Ecto, using microseconds.\n\nThere are other UUID v7 packages, but I wanted the additional clock precision.\n\nUses the method described in **[Section 6.2](https://www.ietf.org/archive/id/draft-ietf-uuidrev-rfc4122bis-14.html#name-monotonicity-and-counters), Method 3**\nfrom [this IETF Draft](https://www.ietf.org/archive/id/draft-ietf-uuidrev-rfc4122bis-14.html)\nto add additional clock precision using microseconds to a version 7 UUID.","ref":"readme.html"},{"type":"extras","title":"Installation - UUIDv7","doc":"The package can be installed by adding `uuid_v7` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:uuid_v7, \"~> 0.2.2\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - UUIDv7","doc":"```elixir\niex> UUIDv7.generate()\n\"018e90d8-06e8-7f9f-bfd7-6730ba98a51b\"\n\niex> UUIDv7.bingenerate()\n<<1, 142, 144, 216, 124, 16, 127, 196, 158, 92, 92, 74, 83, 46, 116, 173>>\n```","ref":"readme.html#usage"},{"type":"extras","title":"Usage with Ecto - UUIDv7","doc":"Use this the same way you would use `Ecto.UUID`. For example:\n\n```elixir\ndefmodule MyApp.Blog.Post do\n  use Ecto.Schema\n\n  @primary_key {:id, UUIDv7, autogenerate: true}\n\n  @foreign_key_type UUIDv7\n\n  schema \"blog_posts\" do\n    field :text, :string\n    # etc.\n  end\nend\n```","ref":"readme.html#usage-with-ecto"}],"content_type":"text/markdown"}